@@ -242,7 +242,7 @@ class VolumeManager(base.ManagerWithFind):
                volume_type=None, user_id=None,
                project_id=None, availability_zone=None,
                metadata=None, imageRef=None, scheduler_hints=None,
-               source_replica=None, multiattach=False):
+               multiattach=False):
         """Create a volume.
 
         :param size: Size of volume in GB
@@ -251,13 +251,12 @@ class VolumeManager(base.ManagerWithFind):
         :param name: Name of the volume
         :param description: Description of the volume
         :param volume_type: Type of volume
-        :param user_id: User id derived from context
-        :param project_id: Project id derived from context
+        :param user_id: User id derived from context (IGNORED)
+        :param project_id: Project id derived from context (IGNORED)
         :param availability_zone: Availability Zone to use
         :param metadata: Optional metadata to set on volume creation
         :param imageRef: reference to an image stored in glance
         :param source_volid: ID of source volume to clone from
-        :param source_replica: ID of source volume to clone replica
         :param scheduler_hints: (optional extension) arbitrary key-value pairs
                             specified by the client to help boot an instance
         :param multiattach: Allow the volume to be attached to more than
@@ -282,15 +281,10 @@ class VolumeManager(base.ManagerWithFind):
                            'name': name,
                            'description': description,
                            'volume_type': volume_type,
-                           'user_id': user_id,
-                           'project_id': project_id,
                            'availability_zone': availability_zone,
-                           'status': "creating",
-                           'attach_status': "detached",
                            'metadata': volume_metadata,
                            'imageRef': imageRef,
                            'source_volid': source_volid,
-                           'source_replica': source_replica,
                            'multiattach': multiattach,
                            }}
 
